summaryrefslogtreecommitdiff
path: root/src/window.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/window.cpp')
-rw-r--r--src/window.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/window.cpp b/src/window.cpp
index f46bf08da..ba360beea 100644
--- a/src/window.cpp
+++ b/src/window.cpp
@@ -1992,9 +1992,10 @@ void HandleKeypress(uint32 raw_key)
if (_focused_window->OnKeyPress(key, keycode) == Window::ES_HANDLED) return;
}
/* Call the event, start with the uppermost window. */
Window *w;
FOR_ALL_WINDOWS_FROM_FRONT(w) {
+ if (w->window_class == WC_MAIN_TOOLBAR) continue;
if (w->OnKeyPress(key, keycode) == Window::ES_HANDLED) return;
}
@@ -1992,9 +1992,10 @@ void HandleKeypress(uint32 raw_key)
if (_focused_window->OnKeyPress(key, keycode) == Window::ES_HANDLED) return;
}
- /* Call the event, start with the uppermost window. */
+ /* Call the event, start with the uppermost window, but ignore the toolbar. */
Window *w;
FOR_ALL_WINDOWS_FROM_FRONT(w) {